
From: Rusty Russell <rusty@rustcorp.com.au>

module_param() and family take a "perms" argument; several people have
incorrectly used "644" instead of "0644".

(I have a patch which checks for sane perms at compile time, but it bloats
modules, so I haven't included it.)

Signed-off-by: Rusty Russell <rusty@rustcorp.com.au> (authored)
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 25-akpm/drivers/pci/hotplug/acpiphp_core.c     |    2 +-
 25-akpm/drivers/pci/hotplug/cpcihp_zt5550.c    |    4 ++--
 25-akpm/drivers/pci/hotplug/cpqphp_core.c      |    4 ++--
 25-akpm/drivers/pci/hotplug/pci_hotplug_core.c |    2 +-
 25-akpm/drivers/pci/hotplug/pciehp_core.c      |    6 +++---
 25-akpm/drivers/pci/hotplug/pcihp_skeleton.c   |    2 +-
 25-akpm/drivers/pci/hotplug/shpchp_core.c      |    6 +++---
 25-akpm/drivers/usb/input/ati_remote.c         |    4 ++--
 25-akpm/fs/jfs/super.c                         |    2 +-
 25-akpm/fs/lockd/svc.c                         |    8 ++++----
 10 files changed, 20 insertions(+), 20 deletions(-)

diff -puN drivers/pci/hotplug/acpiphp_core.c~fix-permissions-on-module_param-usage drivers/pci/hotplug/acpiphp_core.c
--- 25/drivers/pci/hotplug/acpiphp_core.c~fix-permissions-on-module_param-usage	2004-08-15 19:38:46.183766824 -0700
+++ 25-akpm/drivers/pci/hotplug/acpiphp_core.c	2004-08-15 19:38:46.207763176 -0700
@@ -61,7 +61,7 @@ MODULE_AUTHOR(DRIVER_AUTHOR);
 MODULE_DESCRIPTION(DRIVER_DESC);
 MODULE_LICENSE("GPL");
 MODULE_PARM_DESC(debug, "Debugging mode enabled or not");
-module_param(debug, bool, 644);
+module_param(debug, bool, 0644);
 
 /* export the attention callback registration methods */
 EXPORT_SYMBOL_GPL(acpiphp_register_attention);
diff -puN drivers/pci/hotplug/cpcihp_zt5550.c~fix-permissions-on-module_param-usage drivers/pci/hotplug/cpcihp_zt5550.c
--- 25/drivers/pci/hotplug/cpcihp_zt5550.c~fix-permissions-on-module_param-usage	2004-08-15 19:38:46.184766672 -0700
+++ 25-akpm/drivers/pci/hotplug/cpcihp_zt5550.c	2004-08-15 19:38:46.213762264 -0700
@@ -298,7 +298,7 @@ module_exit(zt5550_exit);
 MODULE_AUTHOR(DRIVER_AUTHOR);
 MODULE_DESCRIPTION(DRIVER_DESC);
 MODULE_LICENSE("GPL");
-module_param(debug, bool, 644);
+module_param(debug, bool, 0644);
 MODULE_PARM_DESC(debug, "Debugging mode enabled or not");
-module_param(poll, bool, 644);
+module_param(poll, bool, 0644);
 MODULE_PARM_DESC(poll, "#ENUM polling mode enabled or not");
diff -puN drivers/pci/hotplug/cpqphp_core.c~fix-permissions-on-module_param-usage drivers/pci/hotplug/cpqphp_core.c
--- 25/drivers/pci/hotplug/cpqphp_core.c~fix-permissions-on-module_param-usage	2004-08-15 19:38:46.186766368 -0700
+++ 25-akpm/drivers/pci/hotplug/cpqphp_core.c	2004-08-15 19:38:46.214762112 -0700
@@ -69,10 +69,10 @@ MODULE_AUTHOR(DRIVER_AUTHOR);
 MODULE_DESCRIPTION(DRIVER_DESC);
 MODULE_LICENSE("GPL");
 
-module_param(power_mode, bool, 644);
+module_param(power_mode, bool, 0644);
 MODULE_PARM_DESC(power_mode, "Power mode enabled or not");
 
-module_param(debug, bool, 644);
+module_param(debug, bool, 0644);
 MODULE_PARM_DESC(debug, "Debugging mode enabled or not");
 
 #define CPQHPC_MODULE_MINOR 208
diff -puN drivers/pci/hotplug/pciehp_core.c~fix-permissions-on-module_param-usage drivers/pci/hotplug/pciehp_core.c
--- 25/drivers/pci/hotplug/pciehp_core.c~fix-permissions-on-module_param-usage	2004-08-15 19:38:46.187766216 -0700
+++ 25-akpm/drivers/pci/hotplug/pciehp_core.c	2004-08-15 19:38:46.216761808 -0700
@@ -57,9 +57,9 @@ MODULE_AUTHOR(DRIVER_AUTHOR);
 MODULE_DESCRIPTION(DRIVER_DESC);
 MODULE_LICENSE("GPL");
 
-module_param(pciehp_debug, bool, 644);
-module_param(pciehp_poll_mode, bool, 644);
-module_param(pciehp_poll_time, int, 644);
+module_param(pciehp_debug, bool, 0644);
+module_param(pciehp_poll_mode, bool, 0644);
+module_param(pciehp_poll_time, int, 0644);
 MODULE_PARM_DESC(pciehp_debug, "Debugging mode enabled or not");
 MODULE_PARM_DESC(pciehp_poll_mode, "Using polling mechanism for hot-plug events or not");
 MODULE_PARM_DESC(pciehp_poll_time, "Polling mechanism frequency, in seconds");
diff -puN drivers/pci/hotplug/pci_hotplug_core.c~fix-permissions-on-module_param-usage drivers/pci/hotplug/pci_hotplug_core.c
--- 25/drivers/pci/hotplug/pci_hotplug_core.c~fix-permissions-on-module_param-usage	2004-08-15 19:38:46.189765912 -0700
+++ 25-akpm/drivers/pci/hotplug/pci_hotplug_core.c	2004-08-15 19:38:46.215761960 -0700
@@ -701,7 +701,7 @@ module_exit(pci_hotplug_exit);
 MODULE_AUTHOR(DRIVER_AUTHOR);
 MODULE_DESCRIPTION(DRIVER_DESC);
 MODULE_LICENSE("GPL");
-module_param(debug, bool, 644);
+module_param(debug, bool, 0644);
 MODULE_PARM_DESC(debug, "Debugging mode enabled or not");
 
 EXPORT_SYMBOL_GPL(pci_hotplug_slots_subsys);
diff -puN drivers/pci/hotplug/pcihp_skeleton.c~fix-permissions-on-module_param-usage drivers/pci/hotplug/pcihp_skeleton.c
--- 25/drivers/pci/hotplug/pcihp_skeleton.c~fix-permissions-on-module_param-usage	2004-08-15 19:38:46.190765760 -0700
+++ 25-akpm/drivers/pci/hotplug/pcihp_skeleton.c	2004-08-15 19:38:46.216761808 -0700
@@ -70,7 +70,7 @@ static int num_slots;
 MODULE_AUTHOR(DRIVER_AUTHOR);
 MODULE_DESCRIPTION(DRIVER_DESC);
 MODULE_LICENSE("GPL");
-module_param(debug, bool, 644);
+module_param(debug, bool, 0644);
 MODULE_PARM_DESC(debug, "Debugging mode enabled or not");
 
 static int enable_slot		(struct hotplug_slot *slot);
diff -puN drivers/pci/hotplug/shpchp_core.c~fix-permissions-on-module_param-usage drivers/pci/hotplug/shpchp_core.c
--- 25/drivers/pci/hotplug/shpchp_core.c~fix-permissions-on-module_param-usage	2004-08-15 19:38:46.191765608 -0700
+++ 25-akpm/drivers/pci/hotplug/shpchp_core.c	2004-08-15 19:38:46.217761656 -0700
@@ -57,9 +57,9 @@ MODULE_AUTHOR(DRIVER_AUTHOR);
 MODULE_DESCRIPTION(DRIVER_DESC);
 MODULE_LICENSE("GPL");
 
-module_param(shpchp_debug, bool, 644);
-module_param(shpchp_poll_mode, bool, 644);
-module_param(shpchp_poll_time, int, 644);
+module_param(shpchp_debug, bool, 0644);
+module_param(shpchp_poll_mode, bool, 0644);
+module_param(shpchp_poll_time, int, 0644);
 MODULE_PARM_DESC(shpchp_debug, "Debugging mode enabled or not");
 MODULE_PARM_DESC(shpchp_poll_mode, "Using polling mechanism for hot-plug events or not");
 MODULE_PARM_DESC(shpchp_poll_time, "Polling mechanism frequency, in seconds");
diff -puN drivers/usb/input/ati_remote.c~fix-permissions-on-module_param-usage drivers/usb/input/ati_remote.c
--- 25/drivers/usb/input/ati_remote.c~fix-permissions-on-module_param-usage	2004-08-15 19:38:46.201764088 -0700
+++ 25-akpm/drivers/usb/input/ati_remote.c	2004-08-15 19:38:46.218761504 -0700
@@ -112,11 +112,11 @@
 #define ATI_INPUTNUM      1     /* Which input device to register as */
 
 static unsigned long channel_mask = 0;
-module_param(channel_mask, ulong, 444);
+module_param(channel_mask, ulong, 0444);
 MODULE_PARM_DESC(channel_mask, "Bitmask of remote control channels to ignore");
 
 static int debug = 0;
-module_param(debug, int, 444);
+module_param(debug, int, 0444);
 MODULE_PARM_DESC(debug, "Enable extra debug messages and information");
 
 #define dbginfo(dev, format, arg...) do { if (debug) dev_info(dev , format , ## arg); } while (0)
diff -puN fs/jfs/super.c~fix-permissions-on-module_param-usage fs/jfs/super.c
--- 25/fs/jfs/super.c~fix-permissions-on-module_param-usage	2004-08-15 19:38:46.202763936 -0700
+++ 25-akpm/fs/jfs/super.c	2004-08-15 19:38:46.219761352 -0700
@@ -58,7 +58,7 @@ DECLARE_COMPLETION(jfsIOwait);
 
 #ifdef CONFIG_JFS_DEBUG
 int jfsloglevel = JFS_LOGLEVEL_WARN;
-module_param(jfsloglevel, int, 644);
+module_param(jfsloglevel, int, 0644);
 MODULE_PARM_DESC(jfsloglevel, "Specify JFS loglevel (0, 1 or 2)");
 #endif
 
diff -puN fs/lockd/svc.c~fix-permissions-on-module_param-usage fs/lockd/svc.c
--- 25/fs/lockd/svc.c~fix-permissions-on-module_param-usage	2004-08-15 19:38:46.203763784 -0700
+++ 25-akpm/fs/lockd/svc.c	2004-08-15 19:38:46.219761352 -0700
@@ -409,13 +409,13 @@ MODULE_DESCRIPTION("NFS file locking ser
 MODULE_LICENSE("GPL");
 
 module_param_call(nlm_grace_period, param_set_grace_period, param_get_ulong,
-		  &nlm_grace_period, 644);
+		  &nlm_grace_period, 0644);
 module_param_call(nlm_timeout, param_set_timeout, param_get_ulong,
-		  &nlm_timeout, 644);
+		  &nlm_timeout, 0644);
 module_param_call(nlm_udpport, param_set_port, param_get_int,
-		  &nlm_udpport, 644);
+		  &nlm_udpport, 0644);
 module_param_call(nlm_tcpport, param_set_port, param_get_int,
-		  &nlm_tcpport, 644);
+		  &nlm_tcpport, 0644);
 
 /*
  * Initialising and terminating the module.
_
